# Unit Converter
This contains common conversions such as units convert of __length__, __temperature__, __area__, __volume__, __time__, __weight__.
Specifically contains:
## 1. Lenght
* Meter
* Yard
* Mile
* Foot
* Inch
* Light Year
## 2. Temperature
* Celsius
* Kelvin
* Fahrenheit
## 3. Area
* Square meter
* Hectare
* Square Mile
* Square Yard
* Square Foot
* Square Inch
* Acre
## 4. Volume
* Cubic Meter
* Cubic Kilometer
* Cubic Centimeter
* Cubic Millimeter
* Liter
* Milliliter
* US Gallon
* US Quart
* US Pint
* US Cup
* US Fluid Ounce
* US Table Spoon
* US Tea Spoon
* Imperial Gallon
* Imperial Quart
* Imperial Pint
* Imperial Fluid Ounce
* Imperial Table Spoon
* Imperial Tea Spoon
* Cubic Mile
* Cubic Yard
* cubic Foot
* Cubic Inch
## Time
* Second
* Minute
* Hour
* Day
* Week
* Month
* Year
## weight
* Kilogram
* Gram
* Millimeter
* Metric Ton
* Long Ton
* Short Ton
* Pound
* Ounce
* Carat
* Atomic Mass Unit (Dalton)
